diff src/cpu/sparc/vm/stubRoutines_sparc.hpp @ 1299:9eba43136cb5

6934494: JSR 292 MethodHandles adapters should be generated into their own CodeBlob Summary: Passing a null pointer to an InvokeDynamic function call should lead to a NullPointerException. Reviewed-by: kvn, never
author twisti
date Tue, 16 Mar 2010 11:52:17 +0100
parents a61af66fc99e
children c18cbe5936b8 61b2245abf36
line wrap: on
line diff
--- a/src/cpu/sparc/vm/stubRoutines_sparc.hpp	Thu Mar 11 05:09:20 2010 -0800
+++ b/src/cpu/sparc/vm/stubRoutines_sparc.hpp	Tue Mar 16 11:52:17 2010 +0100
@@ -1,5 +1,5 @@
 /*
- * Copyright 1997-2007 Sun Microsystems, Inc.  All Rights Reserved.
+ * Copyright 1997-2010 Sun Microsystems, Inc.  All Rights Reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -37,8 +37,13 @@
 
 enum /* platform_dependent_constants */ {
   // %%%%%%%% May be able to shrink this a lot
-  code_size1 = 20000,                                        // simply increase if too small (assembler will crash if too small)
-  code_size2 = 20000                                         // simply increase if too small (assembler will crash if too small)
+  code_size1 = 20000,           // simply increase if too small (assembler will crash if too small)
+  code_size2 = 20000            // simply increase if too small (assembler will crash if too small)
+};
+
+// MethodHandles adapters
+enum method_handles_platform_dependent_constants {
+  method_handles_adapters_code_size = 5000
 };
 
 class Sparc {